﻿namespace Cuce.ReportingServices.MSBuild
{
    using System;
    using SSRSWS;
    using Microsoft.Build.Framework;
    using Microsoft.Build.Utilities;

    /// <summary>
    /// ReportingServicesUpdate represetns a update MS Build Task
    /// </summary>
    public class DeleteReport : Microsoft.Build.Utilities.Task
    {

        private readonly IReportingService _reportingService;

        /// <summary>
        /// Initializes a new instance of the <see cref="DeleteReport"/> class.
        /// </summary>
        public DeleteReport()
        {
            _reportingService = new ReportingService();
        }



        /// <summary>
        /// Initializes a new instance of the <see cref="DeleteReport"/> class.
        /// </summary>
        /// <param name="reportingService">The reporting service.</param>
        public DeleteReport(IReportingService reportingService)
        {
            _reportingService = reportingService;
        }

       

        /// <summary>
        /// When overridden in a derived class, executes the task.
        /// </summary>
        /// <returns>
        /// true if the task successfully executed; otherwise, false.
        /// </returns>
        public override bool Execute()
        {
            if (_reportingService == null)
                throw new ArgumentException("ReportingService not set", "ReportingService");

            if (string.IsNullOrEmpty(Url))
                throw new ArgumentException("Url not set", "Url");

            if (string.IsNullOrEmpty(Folder))
                throw new ArgumentException("Folder not set", "Folder");

            if (string.IsNullOrEmpty(Name))
                throw new ArgumentException("Name not set", "Name");


            try
            {
                if (!string.IsNullOrEmpty(CredentialsUserName))
                    _reportingService.Credentials = new System.Net.NetworkCredential(CredentialsUserName, CredentialsPassword, CredentialsDomain);

                if (Proxy)
                    _reportingService.Proxy = new System.Net.WebProxy();

                _reportingService.ListRoles();

                //then upload
                ReportingServiceHelper.DeleteReport(_reportingService, new ReportName(Name, Folder));


              
            }
            catch (ReportException e)
            {
                if (BuildEngine != null)
                    Log.LogErrorFromException(e);

                return false;
            }
            /* catch (Exception e)
            {
                if (this.BuildEngine != null)
                    Log.LogErrorFromException(e);

                if (e.InnerException != null)
                {
                    if (this.BuildEngine != null)
                        Log.LogErrorFromException(e.InnerException);
                }

                return false;
            } */


            return true;
        }

        new TaskLoggingHelper Log { get; set; }

        /// <summary>
        /// Gets or sets the URL.
        /// </summary>
        /// <value>The URL of the SSRS server</value>
        [Required]
        public string Url
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the folder.
        /// </summary>
        /// <value>The folder.</value>
        [Required]
        public string Folder
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>The name of the Reporting Services Report</value>
        [Required]
        public string Name
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the name of the user.
        /// </summary>
        /// <value>The name of the user.</value>
        public string CredentialsUserName
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the users password.
        /// </summary>
        /// <value>The users password.</value>
        public string CredentialsPassword
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the users domain.
        /// </summary>
        /// <value>The users domain.</value>
        public string CredentialsDomain
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="UpdateReport"/> is using a proxy.
        /// </summary>
        /// <value><c>true</c> if proxy; otherwise, <c>false</c>.</value>
        public bool Proxy
        {
            get;
            set;
        }
    }
    
   
}
