﻿using System;

using Microsoft.Build.Framework;
using Microsoft.Build.Utilities;
using System.IO;
using Cuce.ReportingServices.SSRSWS;

namespace Cuce.ReportingServices.MSBuild
{
    /// <summary>
    /// ReportingServicesUpdate represetns a update MS Build Task
    /// </summary>
    public class UpdateReport : Microsoft.Build.Utilities.Task
    {


        /// <summary>
        /// Initializes a new instance of the <see cref="UpdateReport"/> class.
        /// </summary>
        public UpdateReport()
        {
            ReportingService = new ReportingService();
        }



        /// <summary>
        /// Initializes a new instance of the <see cref="UpdateReport"/> class.
        /// </summary>
        /// <param name="reportingService">The reporting service.</param>
        public UpdateReport(IReportingService reportingService)
        {
            ReportingService = reportingService;
        }

        private IReportingService ReportingService = null;

        /// <summary>
        /// When overridden in a derived class, executes the task.
        /// </summary>
        /// <returns>
        /// true if the task successfully executed; otherwise, false.
        /// </returns>
        public override bool Execute()
        {
            if (ReportingService == null)
                throw new ArgumentException("ReportingService not set", "ReportingService");

            if (string.IsNullOrEmpty(Url))
                throw new ArgumentException("Url not set", "Url");

            if (string.IsNullOrEmpty(File))
                throw new ArgumentException("File not set", "File");

            if (string.IsNullOrEmpty(Folder))
                throw new ArgumentException("Folder not set", "Folder");

            if (string.IsNullOrEmpty(Name))
                throw new ArgumentException("Name not set", "Name");

            if (!System.IO.File.Exists(File))
                throw new ArgumentException("File does not Exist", "file");

            ReportingService.Url = Url;

            try
            {
                if (!string.IsNullOrEmpty(CredentialsUserName))
                {
                    if (string.IsNullOrEmpty(CredentialsDomain))
                        ReportingService.Credentials = new System.Net.NetworkCredential(
                                CredentialsUserName, CredentialsPassword);
                    else
                        ReportingService.Credentials = new System.Net.NetworkCredential(
                                CredentialsUserName, CredentialsPassword, CredentialsDomain);


                }

                if (Proxy)
                    ReportingService.Proxy = new System.Net.WebProxy();

                ReportingService.ListRoles();


                //open rdl file
                string rdlstring;



                using (StreamReader streamReader = new StreamReader(File))
                {
                    rdlstring = streamReader.ReadToEnd();
                }


                //then upload
                Warning[] results = ReportingServiceHelper.UploadReport(ReportingService, new ReportName(Name, Folder), rdlstring);


                if (results != null)
                    if (results.Length > 0)
                        throw new ReportException("Upload has warnings", results);

            }
            catch (ReportException e)
            {
                if (this.BuildEngine != null)
                    Log.LogErrorFromException(e);

                return false;
            }
            //catch (Exception e)
            //{
            //    if (this.BuildEngine != null)
            //        Log.LogErrorFromException(e);

            //    if (e.InnerException != null)
            //    {
            //        if (this.BuildEngine != null)
            //            Log.LogErrorFromException(e.InnerException);
            //    }

            //    return false;
            //}


            return true;
        }

        new TaskLoggingHelper  Log { get; set; }

        /// <summary>
        /// Gets or sets the URL.
        /// </summary>
        /// <value>The URL.</value>
        [Required]
        public string Url
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the file.
        /// </summary>
        /// <value>The file.</value>
        [Required]
        public string File
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the folder.
        /// </summary>
        /// <value>The folder.</value>
        [Required]
        public string Folder
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the name.
        /// </summary>
        /// <value>The name.</value>
        [Required]
        public string Name
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the name of the credentials user.
        /// </summary>
        /// <value>The name of the credentials user.</value>
        public string CredentialsUserName
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the credentials password.
        /// </summary>
        /// <value>The credentials password.</value>
        public string CredentialsPassword
        {
            get;
            set;
        }


        /// <summary>
        /// Gets or sets the credentials domain.
        /// </summary>
        /// <value>The credentials domain.</value>
        public string CredentialsDomain
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="UpdateReport"/> is using a proxy.
        /// </summary>
        /// <value><c>true</c> if proxy; otherwise, <c>false</c>.</value>
        public bool Proxy
        {
            get;
            set;
        }
    }

}
